Module error

Module error 

Structs

TuffError
One failure, with the kind of thing that went wrong, what happened, and optionally what to do about it.

Enums

ErrorKind
What kind of failure this is (RFC-105 D6).

Type Aliases

Result