extract_prefix

Function extract_prefix 

pub fn extract_prefix(
    artifact: &PackArtifact,
    prefix: &str,
    output: &Path,
) -> Result<usize>
Extracts files below an artifact prefix into a missing or empty directory.

Returns the number of extracted files.

Errors

Returns an error when the prefix is absent, a path is unsafe, the destination is non-empty, or a filesystem operation fails.