pub enum PolicySubjectKind {
Command,
Read,
Edit,
Mcp,
}Expand description
The kind of thing a rule matches.
Variants
Command
A shell command, matched by a prefix of its arguments.
Read
Reading a file, matched by path pattern.
Edit
Editing or writing a file, matched by path pattern.
Mcp
Calling an MCP tool, matched by server:tool pattern.
Implementations