is_opencode_config

Function is_opencode_config 

pub fn is_opencode_config(relpath: &str) -> bool
Whether a native permissions file is an OpenCode config file, whose permission object maps permission names to actions, or to patterns and actions, and whose order OpenCode reads as precedence.