evaluate

Function evaluate 

pub fn evaluate(
    policy_id: &str,
    policy: &PolicyConfig,
    actions: &[PolicyAction],
    context: EvalContext<'_>,
) -> Result<Option<PolicyDecision>>
The strongest rule of policy that any of actions matches: a deny over an ask, and the first rule of that effect in the policy.