Enums
Constants
- CATALOG_
SOURCE_ IDENTITY - The identity
check_collisionuses for a catalog install: there is no URL, and one catalog entry installed twice is the same source.
check_collision uses for a catalog install: there is no
URL, and one catalog entry installed twice is the same source.