Module tree_diff
tuff_
core
0.16.0
Module tree_
diff
Module Items
Structs
Functions
In crate tuff_
core
tuff_core
Module
tree_
diff
Structs

File
Change
Tree
Comparison
Functions

compare
Imports both directories into one scoped temporary Git repository and compares the resulting Git trees through libgit2. The repository is deleted with
temp
.