compare

Function compare 

pub fn compare(old_root: &Path, new_root: &Path) -> Result<TreeComparison>
Imports both directories into one scoped temporary Git repository and compares the resulting Git trees through libgit2. The repository is deleted with temp.