Module error
tuff_
core
0.3.0
Module error
Module Items
Structs
Enums
Type Aliases
In crate tuff_
core
tuff_core
Module
error
Structs

Tuff
Error
One failure, with the kind of thing that went wrong, what happened, and optionally what to do about it.
Enums

Error
Kind
What kind of failure this is (RFC-105 D6).
Type Aliases

Result