Module tree_diff

Module tree_diff 

Structs

FileChange
TreeComparison

Functions

compare
Imports both directories into one scoped temporary Git repository and compares the resulting Git trees through libgit2. The repository is deleted with temp.